Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
.tox/cov/lib/python3.10/site-packages/confattr/__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
.tox/cov/lib/python3.10/site-packages/confattr/config.py | 263 | 0 | 19 | 126 | 0 | 100%
.tox/cov/lib/python3.10/site-packages/confattr/configfile.py | 733 | 0 | 37 | 300 | 0 | 100%
.tox/cov/lib/python3.10/site-packages/confattr/subprocess_pipe.py | 32 | 0 | 0 | 6 | 0 | 100%
.tox/cov/lib/python3.10/site-packages/confattr/types.py | 111 | 0 | 1 | 44 | 0 | 100%
.tox/cov/lib/python3.10/site-packages/confattr/utils.py | 108 | 0 | 11 | 22 | 0 | 100%
Total | 1252 | 0 | 68 | 498 | 0 | 100%

No items found using the specified filter.